
import java.awt.Color;
import java.awt.BorderLayout;
import java.awt.event.MouseListener;
import java.awt.event.MouseMotionListener;
import java.awt.event.MouseEvent;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;

public class MyMouseTrackerFrame extends JFrame {
	private JPanel mousePanel; // panel in which mouse events will occur
	   private JLabel statusBar; // label that displays event information

	   // MouseTrackerFrame constructor sets up GUI and 
	   // registers mouse event handlers
	   public MyMouseTrackerFrame()
	   {
	      super( "For the demonstration of Mouse Events" );

	      setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
	      mousePanel = new JPanel(); // create panel
	      mousePanel.setBackground( Color.WHITE ); // set background color
	      add( mousePanel, BorderLayout.CENTER ); // add panel to JFrame

	      statusBar = new JLabel( "Mouse outside JPanel" ); 
	      add( statusBar, BorderLayout.SOUTH ); // add label to JFrame

	      // create and register listener for mouse and mouse motion events
	      MouseHandler handler = new MouseHandler(); 
	      mousePanel.addMouseListener( handler ); 
	      mousePanel.addMouseMotionListener( handler ); 
	   } // end MouseTrackerFrame constructor

	   private class MouseHandler implements MouseListener, 
	      MouseMotionListener 
	   {
	      // MouseListener event handlers
	      // handle event when mouse released immediately after press
	      public void mouseClicked( MouseEvent event )
	      {
	         statusBar.setText( String.format( "Clicked at [%d, %d]", 
	            event.getX(), event.getY() ) );
	      } // end method mouseClicked

	      // handle event when mouse pressed
	      public void mousePressed( MouseEvent event )
	      {
	         statusBar.setText( String.format( "Pressed at [%d, %d]", 
	            event.getX(), event.getY() ) );
	      } // end method mousePressed

	      // handle event when mouse released after dragging
	      public void mouseReleased( MouseEvent event )
	      {
	         statusBar.setText( String.format( "Released at [%d, %d]", 
	            event.getX(), event.getY() ) );
	      } // end method mouseReleased

	      // handle event when mouse enters area
	      public void mouseEntered( MouseEvent event )
	      {
	         statusBar.setText( String.format( "Mouse entered at [%d, %d]", 
	            event.getX(), event.getY() ) );
	         mousePanel.setBackground( Color.MAGENTA );
	      } // end method mouseEntered

	      // handle event when mouse exits area
	      public void mouseExited( MouseEvent event )
	      {
	         statusBar.setText( "Mouse outside JPanel" );
	         mousePanel.setBackground( Color.WHITE );
	      } // end method mouseExited

	      // MouseMotionListener event handlers
	      // handle event when user drags mouse with button pressed
	      public void mouseDragged( MouseEvent event )
	      {
	         statusBar.setText( String.format( "Dragged at [%d, %d]", 
	            event.getX(), event.getY() ) );
	      } // end method mouseDragged

	      // handle event when user moves mouse
	      public void mouseMoved( MouseEvent event )
	      {
	         statusBar.setText( String.format( "Moved at [%d, %d]", 
	            event.getX(), event.getY() ) );
	      } // end method mouseMoved
	   } // end inner class MouseHandler
	} // end class MouseTrackerFrame

/**************************************************************************
 * (C) Copyright 1992-2005 by Deitel & Associates, Inc. and               *
 * Pearson Education, Inc. All Rights Reserved.                           *
 *                                                                        *
 Modified by Guoning Chen                                                 *
 *************************************************************************/
